@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010_000;
 
-our $VERSION = '2.036012_003';
+our $VERSION = '2.038002_001';
 use App::Netdisco::Configuration;
 
 =head1 NAME
@@ -153,15 +153,13 @@ connection parameters to match those for your local system (that is, the
 C<name>, C<user> and C<pass>).
 
 In the same file uncomment and edit the C<domain_suffix> setting to be
-appropriate for your local site.
-
-Change the C<community> string setting if your site has different values, and
-uncomment the C<schedule> setting to enable SNMP data gathering from
-devices (this replaces cron jobs in Netdisco 1).
+appropriate for your local site. Change the C<community> string setting if
+your site has different values.
 
 Have a quick read of the other settings to make sure you're happy, then move
-on. See L<Configuration|https://github.com/netdisco/netdisco/wiki/Configuration> for further
-details.
+on. See
+L<Configuration|https://github.com/netdisco/netdisco/wiki/Configuration> for
+further details.
 
 =head1 Initialisation
 
@@ -221,13 +219,11 @@ Then the process below should be run for each installation:
  
  # apply database schema updates, update MIBs and Vendor MACs
  ~/bin/netdisco-deploy
- ~/bin/netdisco-do stats
  
  # restart web service (if you run it)
  ~/bin/netdisco-web restart
  
- # stop old daemon and start new backend worker (wherever you run them)
- ~/bin/netdisco-daemon stop
+ # restart the backend workers (wherever you run them)
  ~/bin/netdisco-backend restart
 
 =head1 Tips and Tricks
@@ -311,7 +307,7 @@ built upon.
 
 =head1 COPYRIGHT AND LICENSE
  
-This software is copyright (c) 2012-2015 by The Netdisco Developer Team.
+This software is copyright (c) 2011-2018 by The Netdisco Developer Team.
  
  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are met:
