@@ -2,7 +2,7 @@ package App::Netdisco::DB::ResultSet::Node;
 use base 'App::Netdisco::DB::ResultSet';
 
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
 __PACKAGE__->load_components(qw/
   +App::Netdisco::DB::ExplicitLocking
@@ -110,8 +110,6 @@ sub delete {
   }
   else {
       foreach my $set (qw/
-        NodeIp
-        NodeNbt
         NodeMonitor
         NodeWireless
       /) {
@@ -121,72 +119,33 @@ sub delete {
       }
 
       # now let DBIC do its thing
-      return $self->next::method();
+      my @retval = ($self->next::method());
+
+      # for node_ip and node_nbt *only* delete if there are no longer
+      # any active nodes referencing the IP or NBT (hence 2nd IN clause).
+      foreach my $set (qw/
+        NodeIp
+        NodeNbt
+      /) {
+        $schema->resultset($set)->search({
+          'me.mac' => { '-in' => $schema->resultset($set)->search({
+              '-and' => [
+                -bool => 'nodes.active',
+                'me.mac' => { '-in' => $nodes->as_query }
+              ]
+            },
+            {
+              columns => 'mac',
+              join => 'nodes',
+              group_by => 'me.mac',
+              having => \[ 'count(nodes.mac) = 0' ],
+            })->as_query,
+          },
+        })->delete;
+      }
+
+      return (wantarray ? @retval : $retval[0]);
   }
 }
 
-=head2 with_multi_ips_as_hashref
-
-This is a modifier for C<search()> which returns a list of hash references
-for nodes within the search criteria with multiple IP addresses.  Each hash
-reference contains the keys:
-
-=over 4
-
-=item mac
-
-Node MAC address.
-
-=item switch
-
-IP address of the device where the node is attached.
-
-=item port
-
-Port on the device where the node is attached.
-
-=item dns
-
-DNS name of the device where the node is attached.
-
-=item name
-
-C<sysName> of the device where the node is attached.
-
-=item ip_count
-
-Count of IP addresses associated with the node.
-
-=item vendor
-
-Vendor string based upon the node OUI.
-
-=back
-
-=cut
-
-sub with_multi_ips_as_hashref {
-  my ( $rs, $cond, $attrs ) = @_;
-
-  my @return = $rs->search(
-    {},
-    { result_class => 'DBIx::Class::ResultClass::HashRefInflator',
-      select       => [ 'mac', 'switch', 'port' ],
-      join         => [qw/device ips oui/],
-      '+columns'   => [
-        { 'dns'      => 'device.dns' },
-        { 'name'     => 'device.name' },
-        { 'ip_count' => { count => 'ips.ip' } },
-        { 'vendor'   => 'oui.company' }
-      ],
-      group_by =>
-        [qw/ me.mac me.switch me.port device.dns device.name oui.company/],
-      having => \[ 'count(ips.ip) > ?', [ count => 1 ] ],
-      order_by => { -desc => [qw/count/] },
-    }
-  )->all;
-
-  return \@return;
-}
-
 1;
