@@ -1,7 +1,7 @@
 package App::Netdisco::Web::Auth::Provider::DBIC;
 
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
 use base 'Dancer::Plugin::Auth::Extensible::Provider::Base';
 
@@ -10,14 +10,17 @@ use base 'Dancer::Plugin::Auth::Extensible::Provider::Base';
 
 use Dancer ':syntax';
 use Dancer::Plugin::DBIC;
-
+use Dancer::Plugin::Passphrase;
 use Digest::MD5;
+use Net::LDAP;
+use Try::Tiny;
 
 sub authenticate_user {
     my ($self, $username, $password) = @_;
     return unless defined $username;
 
     my $user = $self->get_user_details($username) or return;
+    return unless $user->in_storage;
     return $self->match_password($password, $user);
 }
 
@@ -31,9 +34,21 @@ sub get_user_details {
     my $users_table     = $settings->{users_resultset}       || 'User';
     my $username_column = $settings->{users_username_column} || 'username';
 
-    my $user = $database->resultset($users_table)->find({
-        $username_column => $username
-    }) or debug("No such user $username");
+    my $user = try {
+      $database->resultset($users_table)->find({
+          $username_column => $username
+      });
+    };
+
+    # each of these settings permits no user in the database
+    # so create a pseudo user entry instead
+    if (not $user and not setting('validate_remote_user')
+                  and (setting('trust_remote_user')
+                    or setting('trust_x_remote_user')
+                    or setting('no_auth'))) {
+        $user = $database->resultset($users_table)
+          ->new_result({username => $username});
+    }
 
     return $user;
 }
@@ -54,7 +69,9 @@ sub get_user_roles {
     my $roles       = $settings->{roles_relationship} || 'roles';
     my $role_column = $settings->{role_column}        || 'role';
 
-    return [ $user->$roles->get_column( $role_column )->all ];
+    return [ try {
+      $user->$roles->get_column( $role_column )->all;
+    } ];
 }
 
 sub match_password {
@@ -77,16 +94,28 @@ sub match_with_local_pass {
 
     return unless $password and $user->$password_column;
 
-    my $sum = Digest::MD5::md5_hex($password);
-    return ($sum eq $user->$password_column ? 1 : 0);
+    if ($user->$password_column !~ m/^{[A-Z]+}/) {
+        my $sum = Digest::MD5::md5_hex($password);
+
+        if ($sum eq $user->$password_column) {
+            if (setting('safe_password_store')) {
+                # upgrade password if successful, and permitted
+                $user->update({password => passphrase($password)->generate});
+            }
+            return 1;
+        }
+        else {
+            return 0;
+        }
+    }
+    else {
+        return passphrase($password)->matches($user->$password_column);
+    }
 }
 
 sub match_with_ldap {
     my($self, $pass, $user) = @_;
 
-    eval 'require Net::LDAP';
-    if ($@) {error $@; return}
-
     return unless setting('ldap') and ref {} eq ref setting('ldap');
     my $conf = setting('ldap');
 
